@@ -1,5 +1,5 @@
 package Net::Easypost::Address;
-$Net::Easypost::Address::VERSION = '0.16';
+$Net::Easypost::Address::VERSION = '0.17';
 use Moo;
 with qw(Net::Easypost::PostOnBuild);
 with qw(Net::Easypost::Resource);
@@ -66,14 +66,16 @@ sub verify {
         return $self;
     }
     my $verify_response =
-       $self->requester->get( $self->operation . '/' . $self->id . '/verify' );
+       $self->requester->get( 
+          join '/', $self->operation, $self->id, 'verify' 
+       );
 
     croak 'Unable to verify address, failed with message: '
         . $verify_response->{error}
     if $verify_response->{error};
 
     my $new_address = Net::Easypost::Address->new(
-        $verify_response->json->{address}
+        $verify_response->{address}
     );
 
     return $new_address->merge($self, [qw(phone name)]);
@@ -93,7 +95,7 @@ Net::Easypost::Address
 
 =head1 VERSION
 
-version 0.16
+version 0.17
 
 =head1 SYNOPSIS
 
