@@ -1,5 +1,5 @@
 package Net::Easypost::Label;
-$Net::Easypost::Label::VERSION = '0.16';
+$Net::Easypost::Label::VERSION = '0.17';
 use Moo;
 with qw(Net::Easypost::Resource);
 
@@ -42,7 +42,7 @@ has 'image' => (
         croak "Cannot retrieve image for " . $self->filename . " without URL"
             unless $self->has_url;
 
-        return $self->requester->get($self->url)->content->asset->slurp;
+        return $self->requester->get($self->url);
     }
 );
 
@@ -101,7 +101,7 @@ Net::Easypost::Label
 
 =head1 VERSION
 
-version 0.16
+version 0.17
 
 =head1 SYNOPSIS
 
